@@ -181,8 +181,7 @@ class LiveReloadHandler(WebSocketHandler):
             write_posts()
             self.reload_browser()
 
-        elif self._is_changed(g.theme_directory):
-            #: theme changed don't need to reload posts
+        if self._is_changed(g.theme_directory):
             write_posts()
             self.reload_browser()
 
@@ -237,7 +236,7 @@ class LiveReloadHandler(WebSocketHandler):
                 if is_file_changed(path):
                     return True
 
-            return False
+        return False
 
 
 class IndexHandler(RequestHandler):
@@ -257,6 +256,8 @@ class IndexHandler(RequestHandler):
         body = body.replace(
             '</head>', '<script src="/livereload.js"></script></head>'
         )
+        # disable google analytics
+        body = body.replace('google-analytics.com/ga.js', '')
         self.write(body)
 
 
