@@ -17,20 +17,7 @@ def __fetch_themes():
     return content
 
 
-def __load_themes():
-    import time
-    import tempfile
-    path = os.path.join(tempfile.gettempdir(), 'liquidluck.json')
-
-    if not os.path.exists(path) or \
-       os.stat(path).st_mtime + 100 < time.time():
-        content = __fetch_themes()
-        f = open(path, 'w')
-        f.write(content)
-        f.close()
-
-    content = to_unicode(open(path).read())
-
+def __filter_themes(content):
     try:
         import json
         json_decode = json.loads
@@ -41,24 +28,46 @@ def __load_themes():
     repos = json_decode(content)
     themes = {}
     for theme in repos['repositories']:
-        name = theme['name'].replace('liquidluck-theme-', '')
-        name = name.strip().strip('-')
-        theme['name'] = name
-        themes[name] = theme
+        fork = theme['fork']
+        if not fork:
+            name = theme['name'].replace('liquidluck-theme-', '')
+            name = name.strip().strip('-')
+            theme['name'] = name
+            themes[name] = theme
     return themes
 
 
+def __load_themes():
+    import time
+    import tempfile
+    path = os.path.join(tempfile.gettempdir(), 'liquidluck.json')
+
+    if not os.path.exists(path) or \
+       os.stat(path).st_mtime + 600 < time.time():
+        content = __fetch_themes()
+        f = open(path, 'w')
+        f.write(content)
+        f.close()
+
+    content = to_unicode(open(path).read())
+    return __filter_themes(content)
+
+
 SEARCH_TEMPLATE = '''
 Theme: %(name)s
 Author: %(username)s
 Description: %(description)s
 Updated: %(pushed)s
-URL: %(url)s
+Status: %(forks)s forks | %(followers)s followers
+URL: https://github.com/%(username)s/liquidluck-theme-%(name)s
 '''
 
 
-def search(keyword=None, clean=False):
-    themes = __load_themes()
+def search(keyword=None, clean=False, force=False):
+    if force:
+        themes = __filter_themes(__fetch_themes())
+    else:
+        themes = __load_themes()
     available = {}
 
     if keyword:
@@ -84,7 +93,7 @@ def install(keyword=None):
         print("can't find theme %s" % keyword)
         return
     theme = themes[keyword]
-    repo = theme['url']
+    repo = 'https://github.com/%(username)s/liquidluck-theme-%(name)s' % theme
     output = '_themes/%s' % keyword
     import subprocess
     subprocess.call(['git', 'clone', repo, output])
