@@ -11,11 +11,12 @@ Writer, write your content to html.
 import os
 import re
 import datetime
-import hashlib
 import logging
 from jinja2 import Environment, FileSystemLoader
+from jinja2 import contextfilter
 import liquidluck
-from liquidluck.utils import import_object, to_unicode, to_bytes, utf8
+from liquidluck.utils import import_object, get_relative_base
+from liquidluck.utils import to_unicode, utf8
 
 # blog settings
 from liquidluck.options import settings
@@ -23,12 +24,14 @@ from liquidluck.options import settings
 # liquidluck settings
 from liquidluck.options import g
 from liquidluck.filters import xmldatetime, feed_updated
-from liquidluck.filters import tag_url, year_url
+from liquidluck.filters import content_url, tag_url, year_url, static_url
 
 
 class BaseWriter(object):
     """BaseWriter
     """
+    writer_name = 'base'
+
     def start(self):
         raise NotImplementedError
 
@@ -63,6 +66,13 @@ class BaseWriter(object):
         if g.detail_logging:
             logging.info('write %s' % filepath)
         tpl = g.jinja.get_template(template)
+
+        writer = {
+            'class': self.__class__.__name__,
+            'name': self.writer_name,
+            'filepath': filepath,
+        }
+        params['writer'] = writer
         html = tpl.render(params)
         self.write(html, os.path.join(g.output_directory, filepath))
         return
@@ -257,98 +267,27 @@ def get_post_slug(post, slug_format):
     return slug
 
 
-def slug_to_destination(slug, use_index=False):
+def get_post_destination(post, slug_format):
+    slug = get_post_slug(post, slug_format)
     if slug.endswith('.html'):
         return slug
 
-    if slug.endswith('/') and use_index:
-        return slug + 'index.html'
-
     return slug.rstrip('/') + '.html'
 
 
-def permalink(post, prepend_site=False):
+@contextfilter
+def permalink(ctx, post, prepend_site=False):
+    writer = ctx.get('writer')
     slug = get_post_slug(post, settings.permalink)
+
     if prepend_site:
         url = '%s/%s' % (settings.site['url'].rstrip('/'), slug)
+    elif settings.use_relative_url and writer:
+        base = get_relative_base(writer['filepath'])
+        url = '%s/%s' % (base, slug)
     else:
         url = '/%s' % slug
 
     if url.endswith('/index.html'):
         return url[:-10]
     return url
-
-
-def content_url(base, *args):
-    def fix_index(url):
-        if url.endswith('/index.html'):
-            return url[:-10]
-        return url
-
-    args = list(args)
-    base = to_unicode(base)
-
-    if base.startswith('http://') or base.startswith('https://'):
-        prefix = '%s/' % base.rstrip('/')
-    else:
-        prefix = '/'
-        args.insert(0, base)
-
-    args = map(lambda o: to_unicode(o).strip('/'), args)
-    url = '/'.join(args).replace('//', '/').replace(' ', '-')
-    url = prefix + url.lstrip('/')
-    url = to_unicode(fix_index(url.lower()))
-
-    if url.endswith('/'):
-        return url
-
-    if settings.permalink.endswith('.html'):
-        if url.endswith('.html'):
-            return url
-        if url.endswith('.xml'):
-            return url
-        return '%s.html' % url
-
-    if settings.permalink.endswith('/'):
-        if url.endswith('.html'):
-            url = fix_index(url)
-            url = url.rstrip('.html')
-        if url.endswith('.xml'):
-            url = url.rstrip('.xml')
-
-        return '%s/' % url
-
-    if url.endswith('.html'):
-        url = fix_index(url)
-        return url.rstrip('.html')
-    if url.endswith('.xml'):
-        return url.rstrip('.xml')
-    return url
-
-
-_Cache = {}
-
-
-def static_url(base):
-    global _Cache
-
-    def get_hsh(path):
-        if path in _Cache:
-            return _Cache[path]
-        abspath = os.path.join(base, path)
-        if not os.path.exists(abspath):
-            logging.warn('%s does not exists' % path)
-            return ''
-
-        with open(abspath) as f:
-            content = f.read()
-            hsh = hashlib.md5(to_bytes(content)).hexdigest()
-            _Cache[path] = hsh
-            return hsh
-
-    def create_url(path):
-        hsh = get_hsh(path)[:5]
-        url = '%s/%s?v=%s' % (settings.static_prefix.rstrip('/'), path, hsh)
-        return url
-
-    return create_url
