@@ -4,10 +4,12 @@ import os
 from liquidluck.options import g, settings
 from liquidluck.utils import UnicodeDict, walk_dir, copy_to
 from liquidluck.writers.base import BaseWriter, Pagination
-from liquidluck.writers.base import get_post_slug, slug_to_destination
+from liquidluck.writers.base import get_post_destination
 
 
 class PostWriter(BaseWriter):
+    writer_name = 'post'
+
     def __init__(self):
         self._template = self.get('post_template', 'post.html')
 
@@ -20,11 +22,13 @@ class PostWriter(BaseWriter):
             self.render({'post': post}, template, self._dest_of(post))
 
     def _dest_of(self, post):
-        slug = get_post_slug(post, settings.permalink)
-        return os.path.join(g.output_directory, slug_to_destination(slug))
+        dest = get_post_destination(post, settings.permalink)
+        return os.path.join(g.output_directory, dest)
 
 
 class PageWriter(BaseWriter):
+    writer_name = 'page'
+
     def __init__(self):
         self._template = self.get('page_template', 'page.html')
 
@@ -38,6 +42,8 @@ class PageWriter(BaseWriter):
 
 
 class ArchiveWriter(BaseWriter):
+    writer_name = 'archive'
+
     def __init__(self):
         self._template = self.get('archive_template', 'archive.html')
         self._output = self.get(
@@ -80,6 +86,8 @@ class ArchiveWriter(BaseWriter):
 
 
 class ArchiveFeedWriter(ArchiveWriter):
+    writer_name = 'archive_feed'
+
     def __init__(self):
         self._template = self.get('archive_feed_template', 'feed.xml')
         self._output = self.get(
@@ -97,6 +105,8 @@ class ArchiveFeedWriter(ArchiveWriter):
 
 
 class FileWriter(BaseWriter):
+    writer_name = 'file'
+
     def start(self):
         l = len(g.source_directory) + 1
         for f in g.pure_files:
@@ -116,9 +126,10 @@ class StaticWriter(BaseWriter):
 
 
 class YearWriter(ArchiveWriter):
-    _posts = {}
+    writer_name = 'year'
 
     def __init__(self):
+        self._posts = {}
         self._template = self.get('year_template', 'archive.html')
 
         for post in g.public_posts:
@@ -159,9 +170,10 @@ class YearWriter(ArchiveWriter):
 
 
 class TagWriter(ArchiveWriter):
-    _posts = {}
+    writer_name = 'tag'
 
     def __init__(self):
+        self._posts = {}
         self._template = self.get('tag_template', 'archive.html')
 
         for post in g.public_posts:
@@ -201,9 +213,10 @@ class TagWriter(ArchiveWriter):
 
 
 class TagCloudWriter(ArchiveWriter):
-    _posts = {}
+    writer_name = 'tagcloud'
 
     def __init__(self):
+        self._posts = {}
         self._template = self.get('tagcloud_template', 'tagcloud.html')
         if 'tag' in g.resource:
             self._posts = g.resource['tag']
@@ -226,9 +239,10 @@ class TagCloudWriter(ArchiveWriter):
 
 
 class CategoryWriter(ArchiveWriter):
-    _posts = {}
+    writer_name = 'category'
 
     def __init__(self):
+        self._posts = {}
         self._template = self.get('category_template', 'archive.html')
         self._title = self.get('category_title', {})
 
@@ -269,9 +283,10 @@ class CategoryWriter(ArchiveWriter):
 
 
 class CategoryFeedWriter(ArchiveWriter):
-    _posts = {}
+    writer_name = 'category_feed'
 
     def __init__(self):
+        self._posts = {}
         self._template = self.get('category_feed_template', 'feed.xml')
         self._output = self.get('category_feed_output', 'feed.xml')
 
